
#line 3 "src/xbt/graphxml.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer xbt_graph_parse__create_buffer
#define yy_delete_buffer xbt_graph_parse__delete_buffer
#define yy_flex_debug xbt_graph_parse__flex_debug
#define yy_init_buffer xbt_graph_parse__init_buffer
#define yy_flush_buffer xbt_graph_parse__flush_buffer
#define yy_load_buffer_state xbt_graph_parse__load_buffer_state
#define yy_switch_to_buffer xbt_graph_parse__switch_to_buffer
#define yyin xbt_graph_parse_in
#define yyleng xbt_graph_parse_leng
#define yylex xbt_graph_parse_lex
#define yylineno xbt_graph_parse_lineno
#define yyout xbt_graph_parse_out
#define yyrestart xbt_graph_parse_restart
#define yytext xbt_graph_parse_text
#define yywrap xbt_graph_parse_wrap
#define yyalloc xbt_graph_parse_alloc
#define yyrealloc xbt_graph_parse_realloc
#define yyfree xbt_graph_parse_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE xbt_graph_parse_restart(xbt_graph_parse_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int xbt_graph_parse_leng;

extern FILE *xbt_graph_parse_in, *xbt_graph_parse_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE xbt_graph_parse_lex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-xbt_graph_parse_lineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < xbt_graph_parse_leng; ++yyl )\
                    if ( xbt_graph_parse_text[yyl] == '\n' )\
                        --xbt_graph_parse_lineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up xbt_graph_parse_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up xbt_graph_parse_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via xbt_graph_parse_restart()), so that the user can continue scanning by
	 * just pointing xbt_graph_parse_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when xbt_graph_parse_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int xbt_graph_parse_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow xbt_graph_parse_wrap()'s to do buffer switches
 * instead of setting up a fresh xbt_graph_parse_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void xbt_graph_parse_restart (FILE *input_file  );
void xbt_graph_parse__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE xbt_graph_parse__create_buffer (FILE *file,int size  );
void xbt_graph_parse__delete_buffer (YY_BUFFER_STATE b  );
void xbt_graph_parse__flush_buffer (YY_BUFFER_STATE b  );
void xbt_graph_parse_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void xbt_graph_parse_pop_buffer_state (void );

static void xbt_graph_parse_ensure_buffer_stack (void );
static void xbt_graph_parse__load_buffer_state (void );
static void xbt_graph_parse__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER xbt_graph_parse__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE xbt_graph_parse__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE xbt_graph_parse__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE xbt_graph_parse__scan_bytes (yyconst char *bytes,int len  );

void *xbt_graph_parse_alloc (yy_size_t  );
void *xbt_graph_parse_realloc (void *,yy_size_t  );
void xbt_graph_parse_free (void *  );

#define yy_new_buffer xbt_graph_parse__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        xbt_graph_parse_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            xbt_graph_parse__create_buffer(xbt_graph_parse_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        xbt_graph_parse_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            xbt_graph_parse__create_buffer(xbt_graph_parse_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define xbt_graph_parse_wrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *xbt_graph_parse_in = (FILE *) 0, *xbt_graph_parse_out = (FILE *) 0;

typedef int yy_state_type;

extern int xbt_graph_parse_lineno;

int xbt_graph_parse_lineno = 1;

extern char *xbt_graph_parse_text;
#define yytext_ptr xbt_graph_parse_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up xbt_graph_parse_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	xbt_graph_parse_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 92
#define YY_END_OF_BUFFER 93
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[564] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       93,   91,   17,   10,   10,   17,   17,   71,   10,   71,
        5,    6,    5,    8,    9,    8,   87,   79,   80,   88,
       85,   88,   86,   90,   79,   80,   90,   91,   26,   10,
       26,   26,   26,   24,   26,   30,   10,   30,   30,   91,
       91,   30,   91,   45,   10,   45,   45,   45,   43,   45,

       45,   45,   45,   49,   10,   49,   91,   66,   10,   66,
       66,   66,   64,   66,   66,   66,   66,   66,   70,   10,
       70,   88,   87,   10,    0,    2,    2,    0,    4,    7,
       82,   81,    0,    0,    0,    0,    0,    0,    0,   25,
       27,   27,    0,    0,    0,    0,    0,    0,   44,   46,
       46,   46,   46,   46,    0,   65,   67,   67,   67,   67,
       67,   67,   67,    0,    0,    0,    0,    0,    0,    0,
        3,    0,    0,    0,    0,    0,    0,    0,   89,    0,
       27,    0,    0,    0,    0,    0,    0,    0,   46,   46,
       46,   46,    0,    0,   67,   67,   67,   67,   67,   67,

        0,    0,    0,   84,    0,   16,    1,    0,    0,   77,
        0,    0,    0,   74,   73,    0,    0,   27,    0,    0,
       29,    0,    0,    0,    0,    0,    0,   46,   46,   46,
       46,    0,    0,   48,    0,   67,   67,   67,   67,   67,
       67,    0,    0,   69,    0,    0,    0,    0,   78,   72,
        0,    0,    0,   27,    0,   51,    0,   32,   31,   50,
        0,    0,   46,    0,    0,   46,    0,    0,    0,   67,
       67,    0,    0,   67,   67,    0,    0,    0,    0,    0,
       12,    0,   75,   76,   19,   27,    0,   51,   18,   32,
       31,   50,    0,   38,   37,    0,    0,    0,   36,   35,

       46,    0,    0,   63,   62,    0,    0,   67,    0,   55,
       54,   67,   67,    0,    0,    0,    0,    0,   11,   19,
       27,    0,   18,    0,   34,   33,   46,    0,   47,    0,
       53,   52,    0,    0,    0,    0,    0,    0,    0,   68,
        0,    0,    0,    0,   27,    0,   28,   46,    0,   61,
       60,    0,   57,   56,    0,   59,   58,    0,    0,    0,
        0,   27,   46,   83,    0,    0,    0,   27,   46,   46,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       40,   39,    0,   42,   41,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   12,    0,   12,    0,    0,   21,    0,
       20,    0,    0,    0,    0,    0,    0,    0,   23,   22,
        0,    0,    0,    0,    0,    0,    0,   11,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   13,    0,    0,   14,
        0,   15,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    1,    1,    8,    9,    1,
        1,    1,    1,    1,   10,   11,   12,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   14,   15,   16,
       17,   18,   19,    1,   20,   21,   22,   23,   24,   21,
       14,   14,   14,   14,   14,   14,   25,   14,   26,   27,
       14,   14,   28,   29,   14,   14,   14,   14,   30,   14,
       31,    1,   32,    1,   33,    1,   34,   35,   36,   37,

       38,   39,   40,   41,   42,   14,   14,   43,   44,   45,
       46,   47,   48,   49,   50,   51,   52,   53,   14,   54,
       55,   14,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[56] =
    {   0,
        1,    2,    2,    2,    1,    1,    1,    1,    1,    3,
        3,    1,    4,    5,    1,    1,    1,    6,    1,    7,
        7,    7,    7,    7,    5,    5,    5,    5,    5,    5,
        1,    1,    5,    7,    7,    7,    7,    7,    7,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5
    } ;

static yyconst flex_int16_t yy_base[594] =
    {   0,
        0,    0,    0,    3,    6,    9,   24,   27,   11,   14,
       15,   17,   29,   38,   45,   52,   59,   61,   67,   70,
       93,  135,   73,   76,  111,  114,  117,  153,  156,  159,
      176,  179,  182,  185,  200,  203,  206,  209,  225,    0,
      279,  282,  285,  288,  304,    0,  358,  361,  363,  365,
     1585, 1586, 1586,  380,  383,   47,   62, 1586,  386,  171,
     1586, 1586, 1574, 1586, 1586, 1565, 1586, 1578, 1578,  365,
     1586, 1586, 1586, 1586, 1576, 1576, 1546,  375, 1586,  389,
     1559,    0,  195, 1586, 1526, 1586,  398,  391,  399,  402,
      411,  414,  393, 1586,  420, 1557,    0,  401, 1586, 1540,

     1539, 1538, 1525, 1586,  458,  422,  427, 1586,  464, 1552,
        0,  409, 1586, 1535,    1, 1534, 1521, 1532, 1586,  467,
      438, 1560, 1532,  470,   34, 1509, 1586, 1552, 1543, 1586,
     1586, 1586,   69,   40, 1509, 1508, 1506, 1539, 1507, 1586,
        0, 1532, 1514, 1516, 1503, 1505, 1504, 1512, 1586,    0,
     1497, 1512, 1502, 1495, 1499, 1586,    0, 1492, 1507, 1496,
     1496, 1487, 1489, 1499, 1505, 1517, 1516, 1523,  108, 1488,
     1586,   75,    0, 1484, 1484, 1514, 1513, 1481, 1586, 1492,
     1483,  473,  476, 1484, 1489, 1485, 1484, 1480, 1485, 1480,
     1479, 1474,  479,  482, 1481, 1476, 1473, 1474, 1462, 1470,

      485,  502, 1487, 1586, 1490, 1586, 1586,  110, 1464, 1586,
     1491, 1490, 1454, 1586, 1586, 1452, 1455, 1452,  505,  508,
     1586,  511, 1462, 1452, 1460, 1459, 1458,  514, 1452,  530,
     1443,  533,  538, 1586,  546,  550, 1450, 1373,  555, 1387,
     1375,  558,  566, 1586,  571, 1387,  435,  575, 1586, 1586,
     1392, 1389, 1356, 1354,  578,  583, 1346,  588,  595,  598,
      601,  604,  612,  617,  624, 1263,  620,  633,  637,  645,
     1263,  649,  661, 1264, 1250,  653, 1280,  472, 1280,  657,
     1586, 1279, 1586, 1586,  670, 1260,  674,  677,  680,  683,
      686,  694,  697, 1586, 1586,  705,  710,  721, 1586, 1586,

     1248,  729,  732, 1586, 1586,  740,  746,  756,  759, 1586,
     1586,  767,  772,  775, 1264,   32,  104,  153, 1586,  778,
     1226,  783,  788,  793, 1586, 1586, 1230,  801, 1586,  804,
     1586, 1586,  812,  818,  828,  831,  839,  844,  855, 1586,
     1234,  146,  179,  147, 1212,  858, 1586, 1215,  861, 1586,
     1586,  875, 1586, 1586,  883, 1586, 1586, 1111,  891,  175,
      445, 1066,  119, 1586,  894,  181,   89,  897,  900,  903,
      501,  360,  399,  480,  475,  919,  922,  938,  941,  949,
      954,  506,  509,  526,  599,  624,  965,  654,  678,  973,
     1586, 1586,  981, 1586, 1586,  417,  176,  594,  548,  989,

     1058, 1003, 1016,  937,  992,  407,  995,  998, 1001, 1018,
      930,  918,  922,  910, 1026, 1029, 1035, 1038, 1055, 1063,
     1081, 1113,  819,  790,  733,  616,  710, 1073,  721, 1131,
      748,  284, 1149, 1181,  557,  565,  458,  449,  537,  770,
      676,  805,  278,  369,  285,  291, 1076,  293, 1586,  211,
     1586,  708,  693,  727,  162,  110,   76, 1105, 1586, 1586,
      352,  735,  794,    5,  199,  820,  474, 1586, 1144,  850,
     1173, 1199, 1207, 1212,  591,  754, 1220,  799,  831,  749,
      833,  834,  848,  862,  897,  684,  791,  900,  912,  895,
      901,  483,  808,  920,  930,  836,  890,  627,  892,  941,

      962,  971,  993,  818,  873, 1005, 1007,  954,  960,  702,
      872,  963, 1008, 1027, 1092, 1017, 1025, 1151, 1160, 1031,
     1084, 1093, 1152, 1176, 1188, 1161, 1209, 1033, 1087, 1217,
     1221, 1123, 1155, 1088, 1108, 1215, 1216, 1120, 1156, 1218,
     1219, 1222, 1223, 1224, 1225, 1239, 1240, 1226, 1228, 1241,
     1242, 1264, 1258, 1260, 1268, 1277, 1586, 1281, 1285, 1586,
     1288, 1586, 1586, 1306, 1313, 1320, 1327, 1334, 1341, 1348,
     1355, 1362, 1369, 1376, 1381, 1386, 1391, 1398, 1401, 1404,
     1407, 1414, 1418, 1424, 1430, 1436, 1443, 1450, 1457, 1464,
     1471, 1478, 1485

    } ;

static yyconst flex_int16_t yy_def[594] =
    {   0,
      564,  564,  565,  565,  565,  565,  566,  566,  567,  567,
      568,  568,  569,  569,  569,  569,  570,  570,  564,  564,
      571,  571,  572,  572,  572,  572,  564,  564,  572,  572,
      564,  564,  572,  572,  572,  572,  564,  564,  563,   39,
      573,  573,  564,  564,  563,   45,  574,  574,  569,  569,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  575,  563,  563,  575,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  576,  563,  563,  576,

      576,  576,  576,  563,  563,  563,  563,  563,  563,  563,
      577,  563,  563,  577,  577,  577,  577,  577,  563,  563,
      563,  563,  563,  563,  578,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      575,  575,  579,  563,  563,  563,  563,  563,  563,  576,
      576,  576,  576,  576,  580,  563,  577,  577,  577,  577,
      577,  577,  577,  581,  563,  563,  582,  563,  582,  563,
      563,  563,  583,  563,  563,  563,  563,  563,  563,  563,
      575,  584,  584,  563,  563,  563,  563,  563,  576,  576,
      576,  576,  585,  585,  577,  577,  577,  577,  577,  577,

      586,  586,  563,  563,  582,  563,  563,  582,  563,  563,
      583,  563,  563,  563,  563,  563,  563,  575,  563,  584,
      563,  584,  563,  563,  563,  563,  563,  576,  576,  576,
      576,  563,  585,  563,  585,  577,  577,  577,  577,  577,
      577,  563,  586,  563,  586,  563,  582,  587,  563,  563,
      563,  563,  563,  575,  584,  563,  563,  563,  563,  563,
      563,  563,  576,  563,  563,  576,  585,  563,  563,  577,
      577,  563,  563,  577,  577,  586,  563,  582,  587,  587,
      563,  587,  563,  563,  563,  575,  584,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,

      576,  585,  563,  563,  563,  563,  563,  577,  563,  563,
      563,  577,  577,  586,  563,  582,  587,  587,  563,  563,
      575,  584,  563,  563,  563,  563,  576,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  582,  587,  587,  575,  563,  563,  576,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  582,  587,
      587,  575,  576,  563,  582,  587,  587,  575,  576,  576,
      582,  582,  582,  587,  587,  563,  563,  563,  563,  563,
      563,  582,  582,  582,  587,  587,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  582,  582,  582,  587,  587,

      563,  563,  563,  563,  582,  582,  582,  587,  587,  587,
      563,  563,  563,  563,  582,  582,  582,  587,  587,  587,
      588,  589,  563,  563,  563,  563,  582,  582,  582,  587,
      590,  591,  588,  589,  563,  563,  563,  563,  582,  582,
      582,  590,  587,  592,  591,  593,  587,  563,  563,  563,
      563,  582,  582,  582,  592,  563,  593,  587,  563,  563,
      582,  582,  582,  563,  582,  582,  582,  563,  582,  582,
      582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
      582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
      582,  582,  582,  582,  582,  582,  582,  582,  582,  582,

      582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
      582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
      582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
      582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
      582,  582,  582,  582,  582,  582,  582,  582,  582,  582,
      582,  582,  582,  582,  582,  582,  563,  582,  582,  563,
      582,  563,    0,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563

    } ;

static yyconst flex_int16_t yy_nxt[1642] =
    {   0,
      563,   54,   55,   54,   54,   55,   54,   54,   55,   54,
       54,   55,   54,   62,  563,   56,   62,   65,   56,   65,
       63,   57,  468,   63,   57,   59,   55,   59,   59,   55,
       59,   68,   69,   66,  159,   66,   70,   71,  160,   60,
       68,   69,   60,  168,   72,   70,   71,   68,   69,  206,
       73,  125,   70,   72,   68,   69,  169,   73,  342,   70,
       72,   75,   76,   75,   76,  126,  125,   72,   55,   55,
       55,   55,   55,   55,   87,   55,   87,   87,   55,   87,
      127,  172,   78,  174,  456,   78,  175,  172,   88,  210,
       77,   88,   77,   79,   80,   55,   80,   79,   79,   79,

       79,   79,   79,   79,   81,   79,  281,   79,   83,   79,
       84,   79,   87,   55,   87,   87,   55,   87,   55,   55,
       55,  281,  173,   79,   79,  206,   89,  206,  464,   89,
      375,  247,   90,  208,   85,   79,   80,   55,   80,   79,
       79,   79,   79,   79,   79,   79,   81,   79,  343,   79,
       83,   79,   84,   79,   55,   55,   55,   87,   55,   87,
       87,   55,   87,  206,  281,   79,   79,  456,   90,  359,
      281,   88,  369,  370,   88,  128,   85,   55,   55,   55,
       55,   55,   55,   87,   55,   87,   87,   55,   87,  127,
      344,   91,  281,  206,   91,  361,  281,   89,  281,  128,

       89,   87,   55,   87,   87,   55,   87,   55,   55,   55,
       55,   55,   55,  127,  360,   92,  206,  374,   92,  460,
      366,   93,  406,  469,   93,   94,   95,   55,   95,   94,
       94,   94,   94,   94,   94,   94,   96,   94,   97,   94,
       98,   94,   99,   94,   97,   97,   97,   97,   97,   97,
       97,   97,   97,   97,   97,   94,   94,   97,   97,   97,
       97,  100,   97,   97,   97,   97,   97,  101,   97,  102,
       97,  103,   97,   97,   97,   97,   97,   97,   97,   97,
      105,   55,  105,  105,   55,  105,   55,   55,   55,   55,
       55,   55,  443,  443,  106,  281,  282,  106,  459,  456,

      107,  446,  446,  107,  108,  109,   55,  109,  108,  108,
      108,  108,  108,  108,  108,  110,  108,  111,  108,  112,
      108,  113,  108,  111,  111,  111,  111,  111,  111,  111,
      111,  111,  111,  111,  108,  108,  111,  111,  111,  111,
      114,  111,  111,  111,  111,  111,  115,  111,  116,  111,
      111,  111,  111,  117,  118,  111,  111,  111,  111,  120,
       55,  120,  120,   55,  120,   68,   69,   68,   69,  206,
       70,  133,   70,  121,  456,  465,  121,  206,  122,  128,
      122,  124,  124,  124,  124,  124,  124,  124,  124,  124,
      124,  124,  124,  127,  123,  128,  123,  128,  134,  124,

      124,  124,  143,  128,  135,  128,  128,  136,  383,  127,
      143,  127,  137,  128,  139,  128,  206,  127,  128,  127,
      127,  124,  124,  124,  206,  143,  128,  127,  144,  127,
      145,  128,  127,  155,  206,  146,  144,  146,  145,  148,
      127,  145,  128,  147,  384,  127,  146,  416,  144,  164,
      145,  148,  206,  145,  405,  147,  127,  451,  147,  124,
      124,  124,  281,  278,  144,  124,  124,  124,  124,  124,
      124,  124,  124,  124,  219,  219,  219,  219,  219,  219,
      232,  232,  232,  232,  232,  232,  242,  242,  242,  206,
      221,  206,  281,  221,  367,  450,  234,  281,  471,  234,

      206,  316,  244,  242,  242,  242,  219,  219,  219,  219,
      219,  219,  219,  219,  219,  261,  261,  261,  206,  244,
      386,  385,  221,  206,  222,  221,  206,  235,  221,  498,
      262,  264,  264,  264,  232,  232,  232,  382,  245,  232,
      232,  232,  397,  206,  255,  396,  265,  232,  232,  232,
      234,  268,  268,  268,  206,  234,  272,  272,  272,  242,
      242,  242,  398,  234,  452,  281,  269,  242,  242,  242,
      449,  273,  242,  242,  242,  244,  280,  280,  280,  219,
      219,  219,  267,  244,  288,  288,  288,  408,  244,  290,
      290,  290,  281,  282,  448,  221,  291,  291,  291,  292,

      292,  292,  261,  261,  261,  293,  293,  293,  206,  294,
      276,  206,  295,  296,  296,  296,  281,  262,  264,  264,
      264,  232,  232,  232,  287,  298,  298,  298,  297,  299,
      480,  407,  300,  265,  268,  268,  268,  234,  303,  303,
      303,  281,  304,  399,  206,  305,  306,  306,  306,  269,
      272,  272,  272,  438,  242,  242,  242,  302,  280,  280,
      280,  307,  309,  309,  309,  273,  310,  504,  400,  311,
      244,  320,  320,  320,  281,  219,  219,  219,  288,  288,
      288,  323,  323,  323,  290,  290,  290,  291,  291,  291,
      314,  221,  401,  206,  317,  292,  292,  292,  293,  293,

      293,  206,  294,  454,  402,  295,  296,  296,  296,  318,
      206,  324,  324,  324,  322,  325,  403,  492,  326,  206,
      462,  297,  298,  298,  298,  206,  299,  206,  404,  300,
      328,  328,  328,  303,  303,  303,  461,  304,  206,  439,
      305,  306,  306,  306,  206,  516,  329,  330,  330,  330,
      441,  331,  206,  443,  332,  463,  307,  333,  333,  333,
      309,  309,  309,  466,  310,  444,  206,  311,  335,  335,
      335,  206,  334,  337,  337,  337,  339,  339,  339,  320,
      320,  320,  437,  336,  346,  346,  346,  206,  338,  323,
      323,  323,  340,  481,  324,  324,  324,  486,  325,  453,

      347,  326,  328,  328,  328,  330,  330,  330,  206,  331,
      443,  206,  332,  333,  333,  333,  206,  467,  329,  349,
      349,  349,  444,  350,  493,  206,  351,  436,  334,  335,
      335,  335,  352,  352,  352,  206,  353,  206,  484,  354,
      337,  337,  337,  470,  336,  355,  355,  355,  206,  356,
      206,  206,  357,  206,  499,  338,  339,  339,  339,  346,
      346,  346,  349,  349,  349,  206,  350,  206,  435,  351,
      485,  510,  340,  488,  473,  347,  352,  352,  352,  206,
      353,  487,  502,  354,  355,  355,  355,  489,  356,  206,
      206,  357,  365,  365,  365,  365,  365,  365,  376,  376,

      376,  378,  378,  378,  380,  380,  380,  206,  206,  206,
      490,  206,  206,  377,  206,  517,  379,  206,  206,  381,
      376,  376,  376,  387,  387,  387,  511,  388,  496,  206,
      389,  371,  505,  372,  497,  377,  503,  206,  373,  378,
      378,  378,  390,  390,  390,  491,  391,  206,  494,  392,
      380,  380,  380,  500,  379,  393,  393,  393,  206,  394,
      495,  426,  395,  501,  425,  381,  387,  387,  387,  424,
      388,  206,  423,  389,  390,  390,  390,  206,  391,  206,
      206,  392,  393,  393,  393,  414,  394,  506,  206,  395,
      409,  409,  409,  415,  415,  415,  417,  417,  417,  418,

      418,  418,  409,  409,  409,  410,  281,  514,  507,  206,
      206,  508,  206,  515,  419,  281,  518,  410,  281,  420,
      420,  420,  206,  421,  206,  206,  422,  415,  415,  415,
      428,  428,  428,  509,  206,  281,  417,  417,  417,  418,
      418,  418,  206,  206,  206,  512,  206,  513,  206,  413,
      206,  412,  206,  427,  419,  281,  430,  430,  430,  522,
      431,  519,  429,  432,  420,  420,  420,  523,  421,  534,
      520,  422,  281,  526,  428,  428,  428,  458,  458,  458,
      281,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      206,  411,  279,  281,  282,  279,  279,  279,  281,  279,

      440,  206,  368,  528,  206,  206,  458,  458,  458,  206,
      206,  279,  279,  279,  279,  279,  279,  279,  279,  279,
      279,  279,  281,  535,  279,  206,  527,  279,  279,  279,
      281,  279,  430,  430,  430,  521,  431,  206,  540,  432,
      206,  364,  317,  279,  279,  472,  472,  472,  281,  279,
      279,  279,  279,  279,  447,  279,  279,  279,  541,  538,
      279,  206,  529,  279,  279,  279,  281,  279,  206,  206,
      544,  532,  206,  206,  474,  474,  474,  206,  206,  279,
      279,  279,  279,  279,  279,  279,  279,  279,  279,  447,
      206,  539,  279,  206,  524,  279,  279,  279,  281,  279,

      472,  472,  472,  525,  475,  206,  545,  476,  477,  477,
      477,  279,  279,  474,  474,  474,  206,  478,  530,  533,
      479,  477,  477,  477,  206,  482,  206,  536,  483,  206,
      531,  537,  206,  206,  206,  206,  206,  206,  206,  206,
      206,  206,  206,  206,  552,  206,  555,  363,  552,  362,
      555,  542,  543,  358,  546,  547,  206,  206,  206,  206,
      550,  551,  553,  558,  554,  556,  556,  556,  558,  559,
      559,  559,  548,  549,  348,  206,  345,  206,  556,  556,
      556,  557,  561,  561,  561,  560,  559,  559,  559,  561,
      561,  561,  341,  327,  557,  321,  319,  281,  562,  315,

      313,  312,  560,  308,  301,  562,   52,   52,   52,   52,
       52,   52,   52,   53,   53,   53,   53,   53,   53,   53,
       58,   58,   58,   58,   58,   58,   58,   61,   61,   61,
       61,   61,   61,   61,   64,   64,   64,   64,   64,   64,
       64,   67,   67,   67,   67,   67,   67,   67,   74,   74,
       74,   74,   74,   74,   74,   82,   82,   82,   82,   82,
       82,   82,   86,   86,   86,   86,   86,   86,   86,  104,
      104,  104,  104,  104,  104,  104,  119,  119,  119,  119,
      119,  119,  119,  141,  141,  141,  289,  141,  150,  150,
      150,  286,  150,  157,  157,  157,  285,  157,  167,  167,

      167,  167,  167,  284,  167,  182,  283,  182,  193,  277,
      193,  201,  275,  201,  205,  205,  205,  205,  205,  205,
      205,  211,  274,  271,  211,  220,  220,  220,  220,  220,
      220,  233,  233,  233,  233,  233,  233,  243,  243,  243,
      243,  243,  243,  279,  279,  279,  279,  279,  279,  279,
      433,  433,  433,  433,  433,  433,  433,  434,  434,  434,
      434,  434,  434,  434,  442,  442,  442,  442,  442,  442,
      442,  445,  445,  445,  445,  445,  445,  445,  455,  455,
      455,  455,  455,  455,  455,  457,  457,  457,  457,  457,
      457,  457,  270,  266,  263,  260,  259,  258,  257,  256,

      254,  253,  252,  251,  250,  249,  248,  206,  246,  241,
      240,  239,  238,  237,  236,  231,  230,  229,  228,  227,
      226,  225,  224,  223,  218,  217,  216,  215,  214,  213,
      212,  209,  207,  206,  204,  203,  202,  200,  199,  198,
      197,  196,  195,  194,  192,  191,  190,  189,  188,  187,
      186,  185,  184,  183,  181,  180,  179,  178,  177,  176,
      171,  168,  170,  166,  165,  163,  162,  161,  158,  156,
      154,  153,  152,  151,  149,  142,  140,  138,  132,  131,
      132,  131,  130,  129,  563,   51,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,

      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563
    } ;

static yyconst flex_int16_t yy_chk[1642] =
    {   0,
        0,    3,    3,    3,    4,    4,    4,    5,    5,    5,
        6,    6,    6,    9,    0,    3,   10,   11,    4,   12,
        9,    5,  464,   10,    6,    7,    7,    7,    8,    8,
        8,   13,   13,   11,  115,   12,   13,   13,  115,    7,
       14,   14,    8,  125,   13,   14,   14,   15,   15,  316,
       15,   56,   15,   14,   16,   16,  125,   16,  316,   16,
       15,   17,   17,   18,   18,   56,   57,   16,   19,   19,
       19,   20,   20,   20,   23,   23,   23,   24,   24,   24,
       57,  133,   19,  134,  457,   20,  134,  172,   23,  172,
       17,   24,   18,   21,   21,   21,   21,   21,   21,   21,

       21,   21,   21,   21,   21,   21,  367,   21,   21,   21,
       21,   21,   25,   25,   25,   26,   26,   26,   27,   27,
       27,  317,  133,   21,   21,  169,   25,  208,  456,   26,
      367,  208,   27,  169,   21,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,  317,   22,
       22,   22,   22,   22,   28,   28,   28,   29,   29,   29,
       30,   30,   30,  342,  344,   22,   22,  455,   28,  342,
      318,   29,  363,  363,   30,   60,   22,   31,   31,   31,
       32,   32,   32,   33,   33,   33,   34,   34,   34,   60,
      318,   31,  360,  397,   32,  344,  343,   33,  366,   83,

       34,   35,   35,   35,   36,   36,   36,   37,   37,   37,
       38,   38,   38,   83,  343,   35,  465,  366,   36,  450,
      360,   37,  397,  465,   38,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       39,   39,   39,   39,   39,   39,   39,   39,   39,   39,
       41,   41,   41,   42,   42,   42,   43,   43,   43,   44,
       44,   44,  432,  445,   41,  443,  443,   42,  448,  446,

       43,  432,  445,   44,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   47,
       47,   47,   48,   48,   48,   49,   49,   50,   50,  461,
       49,   70,   50,   47,  444,  461,   48,  372,   49,   78,
       50,   54,   54,   54,   55,   55,   55,   59,   59,   59,
       80,   80,   80,   78,   49,   88,   50,   93,   70,   87,

       87,   87,   88,   89,   70,   98,   90,   70,  372,   88,
       89,   93,   70,  112,   78,   91,  373,   89,   92,   98,
       90,   95,   95,   95,  406,   92,  106,  112,   88,   91,
       88,  107,   92,  106,  396,   88,   89,   93,   89,   90,
      106,   90,  121,   89,  373,  107,   90,  406,   91,  121,
       91,   92,  247,   92,  396,   91,  121,  438,   92,  105,
      105,  105,  361,  247,  107,  109,  109,  109,  120,  120,
      120,  124,  124,  124,  182,  182,  182,  183,  183,  183,
      193,  193,  193,  194,  194,  194,  201,  201,  201,  278,
      182,  467,  375,  183,  361,  437,  193,  374,  467,  194,

      492,  278,  201,  202,  202,  202,  219,  219,  219,  220,
      220,  220,  222,  222,  222,  228,  228,  228,  371,  202,
      375,  374,  219,  382,  183,  220,  383,  194,  222,  492,
      228,  230,  230,  230,  232,  232,  232,  371,  202,  233,
      233,  233,  383,  384,  222,  382,  230,  235,  235,  235,
      232,  236,  236,  236,  439,  233,  239,  239,  239,  242,
      242,  242,  384,  235,  439,  399,  236,  243,  243,  243,
      436,  239,  245,  245,  245,  242,  248,  248,  248,  255,
      255,  255,  235,  243,  256,  256,  256,  399,  245,  258,
      258,  258,  248,  248,  435,  255,  259,  259,  259,  260,

      260,  260,  261,  261,  261,  262,  262,  262,  475,  262,
      245,  398,  262,  263,  263,  263,  385,  261,  264,  264,
      264,  267,  267,  267,  255,  265,  265,  265,  263,  265,
      475,  398,  265,  264,  268,  268,  268,  267,  269,  269,
      269,  386,  269,  385,  498,  269,  270,  270,  270,  268,
      272,  272,  272,  426,  276,  276,  276,  267,  280,  280,
      280,  270,  273,  273,  273,  272,  273,  498,  386,  273,
      276,  285,  285,  285,  280,  287,  287,  287,  288,  288,
      288,  289,  289,  289,  290,  290,  290,  291,  291,  291,
      276,  287,  388,  441,  280,  292,  292,  292,  293,  293,

      293,  486,  293,  441,  388,  293,  296,  296,  296,  280,
      453,  297,  297,  297,  287,  297,  389,  486,  297,  510,
      453,  296,  298,  298,  298,  452,  298,  427,  389,  298,
      302,  302,  302,  303,  303,  303,  452,  303,  429,  427,
      303,  306,  306,  306,  454,  510,  302,  307,  307,  307,
      429,  307,  462,  431,  307,  454,  306,  308,  308,  308,
      309,  309,  309,  462,  309,  431,  480,  309,  312,  312,
      312,  476,  308,  313,  313,  313,  314,  314,  314,  320,
      320,  320,  425,  312,  322,  322,  322,  440,  313,  323,
      323,  323,  314,  476,  324,  324,  324,  480,  324,  440,

      322,  324,  328,  328,  328,  330,  330,  330,  487,  330,
      442,  463,  330,  333,  333,  333,  478,  463,  328,  334,
      334,  334,  442,  334,  487,  493,  334,  424,  333,  335,
      335,  335,  336,  336,  336,  504,  336,  466,  478,  336,
      337,  337,  337,  466,  335,  338,  338,  338,  479,  338,
      481,  482,  338,  496,  493,  337,  339,  339,  339,  346,
      346,  346,  349,  349,  349,  483,  349,  470,  423,  349,
      479,  504,  339,  482,  470,  346,  352,  352,  352,  484,
      352,  481,  496,  352,  355,  355,  355,  483,  355,  511,
      505,  355,  359,  359,  359,  365,  365,  365,  368,  368,

      368,  369,  369,  369,  370,  370,  370,  497,  359,  499,
      484,  365,  490,  368,  485,  511,  369,  488,  491,  370,
      376,  376,  376,  377,  377,  377,  505,  377,  490,  489,
      377,  365,  499,  365,  491,  376,  497,  494,  365,  378,
      378,  378,  379,  379,  379,  485,  379,  495,  488,  379,
      380,  380,  380,  494,  378,  381,  381,  381,  500,  381,
      489,  414,  381,  495,  413,  380,  387,  387,  387,  412,
      387,  508,  411,  387,  390,  390,  390,  509,  390,  501,
      512,  390,  393,  393,  393,  404,  393,  500,  502,  393,
      400,  400,  400,  405,  405,  405,  407,  407,  407,  408,

      408,  408,  409,  409,  409,  400,  400,  508,  501,  405,
      503,  502,  407,  509,  408,  408,  512,  409,  409,  410,
      410,  410,  506,  410,  507,  513,  410,  415,  415,  415,
      416,  416,  416,  503,  516,  410,  417,  417,  417,  418,
      418,  418,  517,  415,  514,  506,  416,  507,  520,  403,
      528,  402,  417,  415,  418,  418,  419,  419,  419,  516,
      419,  513,  417,  419,  420,  420,  420,  517,  420,  528,
      514,  420,  419,  520,  428,  428,  428,  447,  447,  447,
      420,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      428,  401,  421,  447,  447,  421,  421,  421,  421,  421,

      428,  521,  362,  522,  529,  534,  458,  458,  458,  515,
      522,  421,  421,  422,  422,  422,  422,  422,  422,  422,
      422,  422,  458,  529,  422,  535,  521,  422,  422,  422,
      422,  422,  430,  430,  430,  515,  430,  538,  534,  430,
      532,  358,  458,  422,  422,  469,  469,  469,  430,  433,
      433,  433,  433,  433,  433,  433,  433,  433,  535,  532,
      433,  469,  523,  433,  433,  433,  433,  433,  518,  523,
      538,  526,  533,  539,  471,  471,  471,  519,  526,  433,
      433,  434,  434,  434,  434,  434,  434,  434,  434,  434,
      471,  533,  434,  524,  518,  434,  434,  434,  434,  434,

      472,  472,  472,  519,  472,  525,  539,  472,  473,  473,
      473,  434,  434,  474,  474,  474,  472,  474,  524,  527,
      474,  477,  477,  477,  473,  477,  527,  530,  477,  474,
      525,  531,  536,  537,  530,  540,  541,  477,  531,  542,
      543,  544,  545,  548,  546,  549,  550,  348,  547,  345,
      551,  536,  537,  341,  540,  541,  546,  547,  550,  551,
      544,  545,  548,  553,  549,  552,  552,  552,  554,  555,
      555,  555,  542,  543,  327,  553,  321,  554,  556,  556,
      556,  552,  558,  558,  558,  555,  559,  559,  559,  561,
      561,  561,  315,  301,  556,  286,  282,  279,  558,  277,

      275,  274,  559,  271,  266,  561,  564,  564,  564,  564,
      564,  564,  564,  565,  565,  565,  565,  565,  565,  565,
      566,  566,  566,  566,  566,  566,  566,  567,  567,  567,
      567,  567,  567,  567,  568,  568,  568,  568,  568,  568,
      568,  569,  569,  569,  569,  569,  569,  569,  570,  570,
      570,  570,  570,  570,  570,  571,  571,  571,  571,  571,
      571,  571,  572,  572,  572,  572,  572,  572,  572,  573,
      573,  573,  573,  573,  573,  573,  574,  574,  574,  574,
      574,  574,  574,  575,  575,  575,  257,  575,  576,  576,
      576,  254,  576,  577,  577,  577,  253,  577,  578,  578,

      578,  578,  578,  252,  578,  579,  251,  579,  580,  246,
      580,  581,  241,  581,  582,  582,  582,  582,  582,  582,
      582,  583,  240,  238,  583,  584,  584,  584,  584,  584,
      584,  585,  585,  585,  585,  585,  585,  586,  586,  586,
      586,  586,  586,  587,  587,  587,  587,  587,  587,  587,
      588,  588,  588,  588,  588,  588,  588,  589,  589,  589,
      589,  589,  589,  589,  590,  590,  590,  590,  590,  590,
      590,  591,  591,  591,  591,  591,  591,  591,  592,  592,
      592,  592,  592,  592,  592,  593,  593,  593,  593,  593,
      593,  593,  237,  231,  229,  227,  226,  225,  224,  223,

      218,  217,  216,  213,  212,  211,  209,  205,  203,  200,
      199,  198,  197,  196,  195,  192,  191,  190,  189,  188,
      187,  186,  185,  184,  181,  180,  178,  177,  176,  175,
      174,  170,  168,  167,  166,  165,  164,  163,  162,  161,
      160,  159,  158,  155,  154,  153,  152,  151,  148,  147,
      146,  145,  144,  143,  142,  139,  138,  137,  136,  135,
      129,  128,  126,  123,  122,  118,  117,  116,  114,  110,
      103,  102,  101,  100,   96,   85,   81,   77,   76,   75,
       69,   68,   66,   63,   51,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,

      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563,  563,  563,  563,  563,  563,  563,  563,  563,  563,
      563
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[93] =
    {   0,
0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 
    1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 
    1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int xbt_graph_parse__flex_debug;
int xbt_graph_parse__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *xbt_graph_parse_text;
/* Validating XML processor for src/xbt/graphxml.dtd.
 *
 * This program was generated with the FleXML XML processor generator.
 * FleXML is Copyright (C) 1999-2005 Kristoffer Rose.  All rights reserved.
 * FleXML is Copyright (C) 2003-2013 Martin Quinson.  All rights reserved.
 * (1.9.6).
 * 
 * There are two, intertwined parts to this program, part A and part B.
 *
 * Part A
 * ------
 * 
 * Some parts, here collectively called "Part A", are found in the 
 * FleXML package.  They are Copyright (C) 1999-2005 Kristoffer Rose
 * and Copyright (C) 2003-2013 Martin Quinson. All rights reserved.
 *
 * You can redistribute, use, perform, display and/or modify "Part A"
 * provided the following two conditions hold:
 *
 * 1. The program is distributed WITHOUT ANY WARRANTY from the author of
 *    FleXML; without even the implied warranty of MERCHANTABILITY or
 *    FITNESS FOR A PARTICULAR PURPOSE.
 *
 * 2. The program distribution conditions do not in any way affect the
 *    distribution conditions of the FleXML system used to generate this
 *    file or any version of FleXML derived from that system.
 *
 * Notice that these are explicit rights granted to you for files
 * generated by the FleXML system.  For your rights in connection with
 * the FleXML system itself please consult the GNU General Public License.
 * 
 * Part B
 * ------
 * 
 * The other parts, here collectively called "Part B", and which came 
 * from the DTD used by FleXML to generate this program, can be 
 * distributed (or not, as the case may be) under the terms of whoever
 * wrote them, provided these terms respect and obey the two conditions 
 * above under the heading "Part A".
 *
 * The author of and contributors to FleXML specifically disclaim
 * any copyright interest in "Part B", unless "Part B" was written 
 * by the author of or contributors to FleXML.
 * 
 */

/* Version strings. */
const char graphxml_flexml_version[] = "1.9.6";

/* ANSI headers. */
#include <stdlib.h> /* for realloc() -- needed here when using flex 2.5.4 */
#include <stdio.h>
#include <string.h>
#include <assert.h>
#include <stdarg.h>
#include <ctype.h>
     
#if defined(_XBT_WIN32) || defined(__WIN32__) || defined(WIN32) || defined(__TOS_WIN__)
# ifndef __STRICT_ANSI__
#  include <io.h>
#  include <process.h>
# endif
#else
# include <unistd.h>
#endif
     
#ifndef FLEXML_INDEXSTACKSIZE
#define FLEXML_INDEXSTACKSIZE 1000
#endif

/* Generated definitions. */
#define FLEXML_yylineno
#ifndef FLEXML_BUFFERSTACKSIZE
#define FLEXML_BUFFERSTACKSIZE 1000000
#endif
#define FLEXML_NEED_BUFFERLIT

/* XML processor api. */
/* FleXML-provided data. */
int graphxml_pcdata_ix;
extern char *graphxml_bufferstack;
#define graphxml_pcdata (graphxml_bufferstack + graphxml_pcdata_ix)
AT_graphxml_node_name AX_graphxml_node_name;
#define A_graphxml_node_name (graphxml_bufferstack + AX_graphxml_node_name)
short int graphxml_node_name_isset;
AT_graphxml_edge_source AX_graphxml_edge_source;
#define A_graphxml_edge_source (graphxml_bufferstack + AX_graphxml_edge_source)
short int graphxml_edge_source_isset;
AT_graphxml_node_position___y AX_graphxml_node_position___y;
#define A_graphxml_node_position___y (graphxml_bufferstack + AX_graphxml_node_position___y)
short int graphxml_node_position___y_isset;
AT_graphxml_node_position___x AX_graphxml_node_position___x;
#define A_graphxml_node_position___x (graphxml_bufferstack + AX_graphxml_node_position___x)
short int graphxml_node_position___x_isset;
AT_graphxml_edge_data AX_graphxml_edge_data;
#define A_graphxml_edge_data (graphxml_bufferstack + AX_graphxml_edge_data)
short int graphxml_edge_data_isset;
AT_graphxml_edge_target AX_graphxml_edge_target;
#define A_graphxml_edge_target (graphxml_bufferstack + AX_graphxml_edge_target)
short int graphxml_edge_target_isset;
AT_graphxml_graph_isDirected AX_graphxml_graph_isDirected;
#define A_graphxml_graph_isDirected AX_graphxml_graph_isDirected
short int graphxml_graph_isDirected_isset;
AT_graphxml_node_label AX_graphxml_node_label;
#define A_graphxml_node_label (graphxml_bufferstack + AX_graphxml_node_label)
short int graphxml_node_label_isset;
AT_graphxml_node_data AX_graphxml_node_data;
#define A_graphxml_node_data (graphxml_bufferstack + AX_graphxml_node_data)
short int graphxml_node_data_isset;
AT_graphxml_edge_label AX_graphxml_edge_label;
#define A_graphxml_edge_label (graphxml_bufferstack + AX_graphxml_edge_label)
short int graphxml_edge_label_isset;
AT_graphxml_edge_length AX_graphxml_edge_length;
#define A_graphxml_edge_length (graphxml_bufferstack + AX_graphxml_edge_length)
short int graphxml_edge_length_isset;
AT_graphxml_edge_name AX_graphxml_edge_name;
#define A_graphxml_edge_name (graphxml_bufferstack + AX_graphxml_edge_name)
short int graphxml_edge_name_isset;

/* XML state. */
#ifdef FLEX_DEBUG
# define ENTER(state)	debug_enter(state,#state)
# define LEAVE		debug_leave()
# define SET(state)	debug_set(state,#state)
  static void debug_enter(int, const char*);
  static void debug_leave(void);
  static void debug_set(int, const char*);
#else
# define ENTER(state)	(yy_push_state(state))
# define LEAVE		(yy_pop_state())
# define SET(state)	BEGIN(state)
#endif

/* Generic actions. */
#define SKIP	/*skip*/
#define SUCCEED        CLEANUP; return 0

#define FAIL	return fail
static int fail(const char*, ...);

enum {flexml_max_err_msg_size = 512};
static char flexml_err_msg[flexml_max_err_msg_size];
const char * graphxml_parse_err_msg()
{
    return flexml_err_msg;
}
static void reset_graphxml_parse_err_msg()
{
    flexml_err_msg[0] = '\0';
}

/* Cleanup */
static void cleanup(void);
#define CLEANUP  cleanup()

/* Text buffer stack handling. */
char *graphxml_bufferstack = NULL;
static int blimit = FLEXML_BUFFERSTACKSIZE;
static int bnext = 1;

static int *indexstack = NULL;
static int ilimit = FLEXML_INDEXSTACKSIZE;
static int inext = 1;

#define BUFFERSET(P)  (P = bnext)
#define BUFFERPUTC(C) (ck_blimit(), graphxml_bufferstack[bnext++] = (C))
#define BUFFERDONE    (BUFFERPUTC('\0'))

#define BUFFERLITERAL(C, P) graphxml_bufferliteral(C, &(P), xbt_graph_parse_text)

/* after this is called, there are at least 2 slots left in the stack */
static int ck_blimit()
{
     if (bnext >= blimit) {
	 blimit += FLEXML_BUFFERSTACKSIZE + 2;
	 {
	     char *temp = (char *) realloc(graphxml_bufferstack, blimit);
	     assert(temp);
	     graphxml_bufferstack = temp;
	 }
     }
     return 0;
}

/* after this is called, there are at least 2 slots left in the stack */
static int ck_ilimit()
{
     if (inext >= ilimit) {
	 ilimit += FLEXML_INDEXSTACKSIZE + 2;
	 {
	     int *temp = (int *) realloc(indexstack, ilimit);
	     assert(temp);
	     indexstack = temp;
	 }
     }
     return 0;
}

#ifdef FLEXML_NEED_BUFFERLIT
static void graphxml_bufferliteral(char c, int* pp, const char* text)
{
   BUFFERSET(*pp);
   if (c) {
      const char *s = strchr(text, c), *e = strrchr(text, c);
      assert(s && e && s <= e);
      ++s;
      while (s < e) {
	 if (isspace(*s)) {
	    BUFFERPUTC(' ');
	    do ++s; while (s < e && isspace(*s));
	 } else
	   BUFFERPUTC(*s++);
      }
   } else {
      const char *s = text;
      while (*s)
	BUFFERPUTC(*s++);
   }
   BUFFERDONE;
}
#endif

static void pushbuffer(int p)
{
    ck_ilimit();
    indexstack[inext++] = p;
    indexstack[inext++] = bnext;    
}

static int popbuffer(void)
{
    assert(inext >= 2);
    bnext = indexstack[--inext];
    return indexstack[--inext];
}

/* General internal entities are `unput' back onto the input stream... */
#define ENTITYTEXT(T) \
  { char *s = (T), *e = s+strlen(s);\
    while (--e >= s) { unput(*e); }}

/* Flex standard options. */
#define YY_NO_INPUT 1
/* Flex user-requested options. */
/* XML character classes (currently restricted to ASCII). */
/* "Common syntactic structures." */
/* "Names and Tokens." */
/* Miscellaneous. */
/* Parser states (flex `exclusive start conditions'):
 *
 * PROLOG	the XML prolog of the document before <?xml...>
 * DOCTYPE	the XML prolog of the document after <?xml...>
 * EPILOG	after the root element
 * INCOMMENT	inside an XML comment <!--....-->
 * INPI		inside an XML PI <?...?>
 * VALUE1	inside a '...'-delimited literal
 * VALUE2	inside a "..."-delimited literal
 * CDATA	inside a <![CDATA[...] ]> section.
 * ROOT_<tag>	expect root element <tag>
 * AL_<tag>	inside the attribute list for <tag>
 * IN_<tag>	inside a <tag> with element contents (ready for end tag)
 * IMPOSSIBLE	dummy to permit disabling rules; must be last
 */

/* State names. */
const char* *graphxml_statenames=NULL;

#define INITIAL 0
#define PROLOG 1
#define DOCTYPE 2
#define EPILOG 3
#define INCOMMENT 4
#define INPI 5
#define VALUE1 6
#define VALUE2 7
#define CDATA 8
#define ROOT_graphxml_graph 9
#define AL_graphxml_graph 10
#define S_graphxml_graph 11
#define S_graphxml_graph_1 12
#define S_graphxml_graph_2 13
#define S_graphxml_graph_3 14
#define S_graphxml_graph_4 15
#define S_graphxml_graph_5 16
#define E_graphxml_graph 17
#define ROOT_graphxml_node 18
#define AL_graphxml_node 19
#define E_graphxml_node 20
#define ROOT_graphxml_edge 21
#define AL_graphxml_edge 22
#define E_graphxml_edge 23
#define IMPOSSIBLE 24

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#if defined(_XBT_WIN32) || defined(__WIN32__) || defined(WIN32) || defined(__TOS_WIN__)
#  ifndef __STRICT_ANSI__
#    include <io.h>
#    include <process.h>
#  endif
#else
#  include <unistd.h>
#endif
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int xbt_graph_parse_lex_destroy (void );

int xbt_graph_parse_get_debug (void );

void xbt_graph_parse_set_debug (int debug_flag  );

YY_EXTRA_TYPE xbt_graph_parse_get_extra (void );

void xbt_graph_parse_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *xbt_graph_parse_get_in (void );

void xbt_graph_parse_set_in  (FILE * in_str  );

FILE *xbt_graph_parse_get_out (void );

void xbt_graph_parse_set_out  (FILE * out_str  );

int xbt_graph_parse_get_leng (void );

char *xbt_graph_parse_get_text (void );

int xbt_graph_parse_get_lineno (void );

void xbt_graph_parse_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int xbt_graph_parse_wrap (void );
#else
extern int xbt_graph_parse_wrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( xbt_graph_parse_text, xbt_graph_parse_leng, 1, xbt_graph_parse_out )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( xbt_graph_parse_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( xbt_graph_parse_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, xbt_graph_parse_in))==0 && ferror(xbt_graph_parse_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(xbt_graph_parse_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int xbt_graph_parse_lex (void);

#define YY_DECL int xbt_graph_parse_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after xbt_graph_parse_text and xbt_graph_parse_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
 /* Bypass Flex's default INITIAL state and begin by parsing the XML prolog. */
 SET(PROLOG);
 reset_graphxml_parse_err_msg();
 graphxml_bufferstack = (char *) malloc(FLEXML_BUFFERSTACKSIZE);
 assert(graphxml_bufferstack);
 #ifdef FLEX_DEBUG
 {
     int i;
     for (i = 0; i < blimit; i++) {
         graphxml_bufferstack[i] = '\377';
     }
 }
 #endif
 graphxml_bufferstack[0] = '\0';
 indexstack = (int *) malloc(FLEXML_INDEXSTACKSIZE * sizeof(int));
 assert(indexstack);
 indexstack[0] = 0;

  /* FleXML_init */
  bnext = inext = 1;
  graphxml_bufferliteral('\0', &bnext, "-1.0");
  graphxml_bufferliteral('\0', &bnext, "-1.0");
  graphxml_bufferliteral('\0', &bnext, "-1.0");
  if(!graphxml_statenames) {graphxml_statenames= (const char **)calloc(IMPOSSIBLE,sizeof(char*));
  graphxml_statenames[PROLOG] = NULL;
  graphxml_statenames[DOCTYPE] = NULL;
  graphxml_statenames[EPILOG] = NULL;
  graphxml_statenames[INCOMMENT] = NULL;
  graphxml_statenames[INPI] = NULL;
  graphxml_statenames[VALUE1] = NULL;
  graphxml_statenames[VALUE2] = NULL;
  graphxml_statenames[CDATA] = NULL;
  graphxml_statenames[ROOT_graphxml_graph] = NULL;
  graphxml_statenames[AL_graphxml_graph] = NULL;
  graphxml_statenames[S_graphxml_graph] = "graph";
  graphxml_statenames[S_graphxml_graph_1] = "graph";
  graphxml_statenames[S_graphxml_graph_2] = "graph";
  graphxml_statenames[S_graphxml_graph_3] = "graph";
  graphxml_statenames[S_graphxml_graph_4] = "graph";
  graphxml_statenames[S_graphxml_graph_5] = "graph";
  graphxml_statenames[E_graphxml_graph] = "graph";
  graphxml_statenames[ROOT_graphxml_node] = NULL;
  graphxml_statenames[AL_graphxml_node] = NULL;
  graphxml_statenames[E_graphxml_node] = "node";
  graphxml_statenames[ROOT_graphxml_edge] = NULL;
  graphxml_statenames[AL_graphxml_edge] = NULL;
  graphxml_statenames[E_graphxml_edge] = "edge";
  }

 /* COMMENTS and PIs: handled uniformly for efficiency. */

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! xbt_graph_parse_in )
			xbt_graph_parse_in = stdin;

		if ( ! xbt_graph_parse_out )
			xbt_graph_parse_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			xbt_graph_parse_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				xbt_graph_parse__create_buffer(xbt_graph_parse_in,YY_BUF_SIZE );
		}

		xbt_graph_parse__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of xbt_graph_parse_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 564 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1586 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < xbt_graph_parse_leng; ++yyl )
				if ( xbt_graph_parse_text[yyl] == '\n' )
					   
    xbt_graph_parse_lineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
ENTER(INCOMMENT);
	YY_BREAK
case 2:
YY_RULE_SETUP
ENTER(INPI);
	YY_BREAK

case 3:
YY_RULE_SETUP
LEAVE;
	YY_BREAK
case 4:
case 5:
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
SKIP;
	YY_BREAK
case YY_STATE_EOF(INCOMMENT):
FAIL("EOF in comment.");
	YY_BREAK

case 7:
YY_RULE_SETUP
LEAVE;
	YY_BREAK
case 8:
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
SKIP;
	YY_BREAK
case YY_STATE_EOF(INPI):
FAIL("EOF in PI (processing instruction).");
	YY_BREAK

/* SPACES: skipped uniformly */
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
SKIP;
	YY_BREAK
/* PROLOG: determine root element and process it. */

case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
SET(DOCTYPE); 
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
FAIL("Bad declaration %s.",xbt_graph_parse_text);
	YY_BREAK

case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
SET(ROOT_graphxml_edge);
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
SET(ROOT_graphxml_node);
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
SET(ROOT_graphxml_graph);
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
FAIL("Bad declaration %s.",xbt_graph_parse_text);
	YY_BREAK
case 17:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in prolog.", xbt_graph_parse_text[0]);
	YY_BREAK
case YY_STATE_EOF(PROLOG):
case YY_STATE_EOF(DOCTYPE):
FAIL("EOF in prolog.");
	YY_BREAK

/* RULES DERIVED FROM DTD. */
/* <!-- Small DTD for xbt graphs. -->  */
/*     isDirected (true|false) "true"
  * >  */
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <graph> is not allowed here.");
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
{
  AX_graphxml_graph_isDirected = A_graphxml_graph_isDirected_true;
  graphxml_graph_isDirected_isset = 0;
  ENTER(AL_graphxml_graph); pushbuffer(0);
  }
	YY_BREAK

case 20:
/* rule 20 can match eol */
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
A_graphxml_graph_isDirected = A_graphxml_graph_isDirected_true;
	YY_BREAK
case 22:
/* rule 22 can match eol */
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
A_graphxml_graph_isDirected = A_graphxml_graph_isDirected_false;
	YY_BREAK
case 24:
YY_RULE_SETUP
{
  LEAVE; STag_graphxml_graph();graphxml_pcdata_ix = 0; ENTER(S_graphxml_graph);
 }
	YY_BREAK
case 25:
YY_RULE_SETUP
{
  LEAVE; STag_graphxml_graph(); graphxml_pcdata_ix = 0; ETag_graphxml_graph(); popbuffer(); /* attribute */
  switch (YY_START) {
   case ROOT_graphxml_graph: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 26:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of graph element.", xbt_graph_parse_text[0]);
	YY_BREAK
case 27:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `graph' element start tag.",xbt_graph_parse_text);
	YY_BREAK
case YY_STATE_EOF(AL_graphxml_graph):
FAIL("EOF in attribute list of `graph' element.");
	YY_BREAK

case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_graphxml_graph();
  popbuffer(); /* attribute */
  switch (YY_START) {
   case ROOT_graphxml_graph: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</graph>' expected.",xbt_graph_parse_text);
	YY_BREAK
case 30:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</graph>' expected.",xbt_graph_parse_text[0]);
	YY_BREAK
case YY_STATE_EOF(S_graphxml_graph_1):
case YY_STATE_EOF(E_graphxml_graph):
case YY_STATE_EOF(S_graphxml_graph_3):
case YY_STATE_EOF(S_graphxml_graph_5):
case YY_STATE_EOF(S_graphxml_graph):
FAIL("Premature EOF: `</graph>' expected.");
	YY_BREAK

/*     label           CDATA                ""
  *     name            CDATA                #REQUIRED
  *     data            CDATA                ""
  *     position_x	    CDATA		 "-1.0"
  *     position_y	    CDATA		 "-1.0"
  * >  */
case 31:
/* rule 31 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <node> is not allowed here.");
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
{
  AX_graphxml_node_label = 0;
  graphxml_node_label_isset = 0;
  AX_graphxml_node_name = 0;
  graphxml_node_name_isset = 0;
  AX_graphxml_node_data = 0;
  graphxml_node_data_isset = 0;
  AX_graphxml_node_position___x = 1;
  graphxml_node_position___x_isset = 0;
  AX_graphxml_node_position___y = 6;
  graphxml_node_position___y_isset = 0;
  ENTER(AL_graphxml_node); pushbuffer(0);
  }
	YY_BREAK

case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
if (graphxml_node_label_isset != 0) {FAIL("Multiple definition of attribute label in <graphxml_node>");} graphxml_node_label_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_node_label);
	YY_BREAK
case 34:
/* rule 34 can match eol */
YY_RULE_SETUP
if (graphxml_node_label_isset != 0) {FAIL("Multiple definition of attribute label in <graphxml_node>");}  graphxml_node_label_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_node_label);
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
if (graphxml_node_name_isset != 0) {FAIL("Multiple definition of attribute name in <graphxml_node>");} graphxml_node_name_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_node_name);
	YY_BREAK
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
if (graphxml_node_name_isset != 0) {FAIL("Multiple definition of attribute name in <graphxml_node>");}  graphxml_node_name_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_node_name);
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
if (graphxml_node_data_isset != 0) {FAIL("Multiple definition of attribute data in <graphxml_node>");} graphxml_node_data_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_node_data);
	YY_BREAK
case 38:
/* rule 38 can match eol */
YY_RULE_SETUP
if (graphxml_node_data_isset != 0) {FAIL("Multiple definition of attribute data in <graphxml_node>");}  graphxml_node_data_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_node_data);
	YY_BREAK
case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
if (graphxml_node_position___x_isset != 0) {FAIL("Multiple definition of attribute position_x in <graphxml_node>");} graphxml_node_position___x_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_node_position___x);
	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
if (graphxml_node_position___x_isset != 0) {FAIL("Multiple definition of attribute position_x in <graphxml_node>");}  graphxml_node_position___x_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_node_position___x);
	YY_BREAK
case 41:
/* rule 41 can match eol */
YY_RULE_SETUP
if (graphxml_node_position___y_isset != 0) {FAIL("Multiple definition of attribute position_y in <graphxml_node>");} graphxml_node_position___y_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_node_position___y);
	YY_BREAK
case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
if (graphxml_node_position___y_isset != 0) {FAIL("Multiple definition of attribute position_y in <graphxml_node>");}  graphxml_node_position___y_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_node_position___y);
	YY_BREAK
case 43:
YY_RULE_SETUP
{
  if (!AX_graphxml_node_name) FAIL("Required attribute `name' not set for `node' element.");
  LEAVE; STag_graphxml_node();graphxml_pcdata_ix = 0; ENTER(E_graphxml_node);
 }
	YY_BREAK
case 44:
YY_RULE_SETUP
{
  if (!AX_graphxml_node_name) FAIL("Required attribute `name' not set for `node' element.");
  LEAVE; STag_graphxml_node(); graphxml_pcdata_ix = 0; ETag_graphxml_node(); popbuffer(); /* attribute */
  switch (YY_START) {
   case S_graphxml_graph_2: case S_graphxml_graph_3: case S_graphxml_graph: SET(S_graphxml_graph_3); break;
   case ROOT_graphxml_node: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 45:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of node element.", xbt_graph_parse_text[0]);
	YY_BREAK
case 46:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `node' element start tag.",xbt_graph_parse_text);
	YY_BREAK
case YY_STATE_EOF(AL_graphxml_node):
FAIL("EOF in attribute list of `node' element.");
	YY_BREAK

case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_graphxml_node();
  popbuffer(); /* attribute */
  switch (YY_START) {
   case S_graphxml_graph_2: case S_graphxml_graph_3: case S_graphxml_graph: SET(S_graphxml_graph_3); break;
   case ROOT_graphxml_node: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 48:
/* rule 48 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</node>' expected.",xbt_graph_parse_text);
	YY_BREAK
case 49:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</node>' expected.",xbt_graph_parse_text[0]);
	YY_BREAK
case YY_STATE_EOF(E_graphxml_node):
FAIL("Premature EOF: `</node>' expected.");
	YY_BREAK

/*     label           CDATA                ""
  *     name            CDATA               #IMPLIED
  *     source          CDATA               #REQUIRED
  *     target          CDATA               #REQUIRED
  *     length          CDATA               "-1.0"
  *     data            CDATA               ""
  * >  */
case 50:
/* rule 50 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <edge> is not allowed here.");
	YY_BREAK
case 51:
/* rule 51 can match eol */
YY_RULE_SETUP
{
  AX_graphxml_edge_label = 0;
  graphxml_edge_label_isset = 0;
  AX_graphxml_edge_name = 0;
  graphxml_edge_name_isset = 0;
  AX_graphxml_edge_source = 0;
  graphxml_edge_source_isset = 0;
  AX_graphxml_edge_target = 0;
  graphxml_edge_target_isset = 0;
  AX_graphxml_edge_length = 11;
  graphxml_edge_length_isset = 0;
  AX_graphxml_edge_data = 0;
  graphxml_edge_data_isset = 0;
  ENTER(AL_graphxml_edge); pushbuffer(0);
  }
	YY_BREAK

case 52:
/* rule 52 can match eol */
YY_RULE_SETUP
if (graphxml_edge_label_isset != 0) {FAIL("Multiple definition of attribute label in <graphxml_edge>");} graphxml_edge_label_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_edge_label);
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
if (graphxml_edge_label_isset != 0) {FAIL("Multiple definition of attribute label in <graphxml_edge>");}  graphxml_edge_label_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_edge_label);
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
if (graphxml_edge_name_isset != 0) {FAIL("Multiple definition of attribute name in <graphxml_edge>");} graphxml_edge_name_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_edge_name);
	YY_BREAK
case 55:
/* rule 55 can match eol */
YY_RULE_SETUP
if (graphxml_edge_name_isset != 0) {FAIL("Multiple definition of attribute name in <graphxml_edge>");}  graphxml_edge_name_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_edge_name);
	YY_BREAK
case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
if (graphxml_edge_source_isset != 0) {FAIL("Multiple definition of attribute source in <graphxml_edge>");} graphxml_edge_source_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_edge_source);
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
if (graphxml_edge_source_isset != 0) {FAIL("Multiple definition of attribute source in <graphxml_edge>");}  graphxml_edge_source_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_edge_source);
	YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
if (graphxml_edge_target_isset != 0) {FAIL("Multiple definition of attribute target in <graphxml_edge>");} graphxml_edge_target_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_edge_target);
	YY_BREAK
case 59:
/* rule 59 can match eol */
YY_RULE_SETUP
if (graphxml_edge_target_isset != 0) {FAIL("Multiple definition of attribute target in <graphxml_edge>");}  graphxml_edge_target_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_edge_target);
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
if (graphxml_edge_length_isset != 0) {FAIL("Multiple definition of attribute length in <graphxml_edge>");} graphxml_edge_length_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_edge_length);
	YY_BREAK
case 61:
/* rule 61 can match eol */
YY_RULE_SETUP
if (graphxml_edge_length_isset != 0) {FAIL("Multiple definition of attribute length in <graphxml_edge>");}  graphxml_edge_length_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_edge_length);
	YY_BREAK
case 62:
/* rule 62 can match eol */
YY_RULE_SETUP
if (graphxml_edge_data_isset != 0) {FAIL("Multiple definition of attribute data in <graphxml_edge>");} graphxml_edge_data_isset = 1; ENTER(VALUE1); BUFFERSET(AX_graphxml_edge_data);
	YY_BREAK
case 63:
/* rule 63 can match eol */
YY_RULE_SETUP
if (graphxml_edge_data_isset != 0) {FAIL("Multiple definition of attribute data in <graphxml_edge>");}  graphxml_edge_data_isset = 1; ENTER(VALUE2); BUFFERSET(AX_graphxml_edge_data);
	YY_BREAK
case 64:
YY_RULE_SETUP
{
  if (!AX_graphxml_edge_source) FAIL("Required attribute `source' not set for `edge' element.");
  if (!AX_graphxml_edge_target) FAIL("Required attribute `target' not set for `edge' element.");
  LEAVE; STag_graphxml_edge();graphxml_pcdata_ix = 0; ENTER(E_graphxml_edge);
 }
	YY_BREAK
case 65:
YY_RULE_SETUP
{
  if (!AX_graphxml_edge_source) FAIL("Required attribute `source' not set for `edge' element.");
  if (!AX_graphxml_edge_target) FAIL("Required attribute `target' not set for `edge' element.");
  LEAVE; STag_graphxml_edge(); graphxml_pcdata_ix = 0; ETag_graphxml_edge(); popbuffer(); /* attribute */
  switch (YY_START) {
   case S_graphxml_graph_1: case S_graphxml_graph_3: case S_graphxml_graph_5: case S_graphxml_graph_4: case S_graphxml_graph: SET(S_graphxml_graph_5); break;
   case ROOT_graphxml_edge: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 66:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of edge element.", xbt_graph_parse_text[0]);
	YY_BREAK
case 67:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `edge' element start tag.",xbt_graph_parse_text);
	YY_BREAK
case YY_STATE_EOF(AL_graphxml_edge):
FAIL("EOF in attribute list of `edge' element.");
	YY_BREAK

case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_graphxml_edge();
  popbuffer(); /* attribute */
  switch (YY_START) {
   case S_graphxml_graph_1: case S_graphxml_graph_3: case S_graphxml_graph_5: case S_graphxml_graph_4: case S_graphxml_graph: SET(S_graphxml_graph_5); break;
   case ROOT_graphxml_edge: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 69:
/* rule 69 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</edge>' expected.",xbt_graph_parse_text);
	YY_BREAK
case 70:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</edge>' expected.",xbt_graph_parse_text[0]);
	YY_BREAK
case YY_STATE_EOF(E_graphxml_edge):
FAIL("Premature EOF: `</edge>' expected.");
	YY_BREAK

/* EPILOG: after the root element. */

case 71:
YY_RULE_SETUP
{SET(PROLOG); yyless(0); CLEANUP; return -1;}
	YY_BREAK
case YY_STATE_EOF(EPILOG):
SUCCEED;
	YY_BREAK

/* CHARACTER DATA. */

/* Non-defined standard entities... */
case 72:
YY_RULE_SETUP
BUFFERPUTC('&');
	YY_BREAK
case 73:
YY_RULE_SETUP
BUFFERPUTC('<');
	YY_BREAK
case 74:
YY_RULE_SETUP
BUFFERPUTC('>');
	YY_BREAK
case 75:
YY_RULE_SETUP
BUFFERPUTC('\'');
	YY_BREAK
case 76:
YY_RULE_SETUP
BUFFERPUTC('"');
	YY_BREAK
/* Character entities. */
case 77:
YY_RULE_SETUP
BUFFERPUTC((unsigned char)atoi(xbt_graph_parse_text+2));
	YY_BREAK
case 78:
YY_RULE_SETUP
BUFFERPUTC((unsigned char)strtol(xbt_graph_parse_text+3,NULL,16));
	YY_BREAK

case 79:
/* rule 79 can match eol */
case 80:
/* rule 80 can match eol */
case 81:
/* rule 81 can match eol */
case 82:
/* rule 82 can match eol */
YY_RULE_SETUP
BUFFERPUTC('\n');
	YY_BREAK

case 83:
YY_RULE_SETUP
ENTER(CDATA);
	YY_BREAK
case 84:
YY_RULE_SETUP
FAIL("Unexpected `]""]>' in character data.");
	YY_BREAK

case 85:
YY_RULE_SETUP
BUFFERDONE; LEAVE;
	YY_BREAK
case YY_STATE_EOF(VALUE1):
FAIL("EOF in literal (\"'\" expected).");
	YY_BREAK

case 86:
YY_RULE_SETUP
BUFFERDONE; LEAVE;
	YY_BREAK
case YY_STATE_EOF(VALUE2):
FAIL("EOF in literal (`\"' expected).");
	YY_BREAK

case 87:
/* rule 87 can match eol */
YY_RULE_SETUP
BUFFERPUTC(xbt_graph_parse_text[0]);
	YY_BREAK
case 88:
YY_RULE_SETUP
FAIL("Spurious `%c' in character data.",xbt_graph_parse_text[0]);
	YY_BREAK

case 89:
YY_RULE_SETUP
LEAVE;
	YY_BREAK
/* "]""]"		BUFFERPUTC(xbt_graph_parse_text[0]); BUFFERPUTC(xbt_graph_parse_text[1]); */
case 90:
YY_RULE_SETUP
BUFFERPUTC(xbt_graph_parse_text[0]);
	YY_BREAK
case YY_STATE_EOF(CDATA):
FAIL("EOF in CDATA section.");
	YY_BREAK

/* Impossible rules to avoid warnings from flex(1). */
/* Ideally, this should be replaced by code in flexml.pl that
    generates just the states not covered by other rules. */

case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
FAIL("Syntax error on character `%c'.", xbt_graph_parse_text[0]);
	YY_BREAK

case 92:
YY_RULE_SETUP
ECHO;
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ROOT_graphxml_graph):
case YY_STATE_EOF(S_graphxml_graph_2):
case YY_STATE_EOF(S_graphxml_graph_4):
case YY_STATE_EOF(ROOT_graphxml_node):
case YY_STATE_EOF(ROOT_graphxml_edge):
case YY_STATE_EOF(IMPOSSIBLE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed xbt_graph_parse_in at a new source and called
			 * xbt_graph_parse_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = xbt_graph_parse_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( xbt_graph_parse_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * xbt_graph_parse_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of xbt_graph_parse_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					xbt_graph_parse_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			xbt_graph_parse_restart(xbt_graph_parse_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) xbt_graph_parse_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 564 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 564 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 563);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					xbt_graph_parse_restart(xbt_graph_parse_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( xbt_graph_parse_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve xbt_graph_parse_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    xbt_graph_parse_lineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void xbt_graph_parse_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        xbt_graph_parse_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            xbt_graph_parse__create_buffer(xbt_graph_parse_in,YY_BUF_SIZE );
	}

	xbt_graph_parse__init_buffer(YY_CURRENT_BUFFER,input_file );
	xbt_graph_parse__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void xbt_graph_parse__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		xbt_graph_parse_pop_buffer_state();
	 *		xbt_graph_parse_push_buffer_state(new_buffer);
     */
	xbt_graph_parse_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	xbt_graph_parse__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (xbt_graph_parse_wrap()) processing, but the only time this flag
	 * is looked at is after xbt_graph_parse_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void xbt_graph_parse__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	xbt_graph_parse_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE xbt_graph_parse__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) xbt_graph_parse_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in xbt_graph_parse__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) xbt_graph_parse_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in xbt_graph_parse__create_buffer()" );

	b->yy_is_our_buffer = 1;

	xbt_graph_parse__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with xbt_graph_parse__create_buffer()
 * 
 */
    void xbt_graph_parse__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		xbt_graph_parse_free((void *) b->yy_ch_buf  );

	xbt_graph_parse_free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a xbt_graph_parse_restart() or at EOF.
 */
    static void xbt_graph_parse__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	xbt_graph_parse__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then xbt_graph_parse__init_buffer was _probably_
     * called from xbt_graph_parse_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void xbt_graph_parse__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		xbt_graph_parse__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void xbt_graph_parse_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	xbt_graph_parse_ensure_buffer_stack();

	/* This block is copied from xbt_graph_parse__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from xbt_graph_parse__switch_to_buffer. */
	xbt_graph_parse__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void xbt_graph_parse_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	xbt_graph_parse__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		xbt_graph_parse__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void xbt_graph_parse_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)xbt_graph_parse_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in xbt_graph_parse_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)xbt_graph_parse_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in xbt_graph_parse_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE xbt_graph_parse__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) xbt_graph_parse_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in xbt_graph_parse__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	xbt_graph_parse__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to xbt_graph_parse_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       xbt_graph_parse__scan_bytes() instead.
 */
YY_BUFFER_STATE xbt_graph_parse__scan_string (yyconst char * yystr )
{
    
	return xbt_graph_parse__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to xbt_graph_parse_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE xbt_graph_parse__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) xbt_graph_parse_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in xbt_graph_parse__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = xbt_graph_parse__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in xbt_graph_parse__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) xbt_graph_parse_alloc(new_size  );

		else
			(yy_start_stack) = (int *) xbt_graph_parse_realloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up xbt_graph_parse_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		xbt_graph_parse_text[xbt_graph_parse_leng] = (yy_hold_char); \
		(yy_c_buf_p) = xbt_graph_parse_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		xbt_graph_parse_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int xbt_graph_parse_get_lineno  (void)
{
        
    return xbt_graph_parse_lineno;
}

/** Get the input stream.
 * 
 */
FILE *xbt_graph_parse_get_in  (void)
{
        return xbt_graph_parse_in;
}

/** Get the output stream.
 * 
 */
FILE *xbt_graph_parse_get_out  (void)
{
        return xbt_graph_parse_out;
}

/** Get the length of the current token.
 * 
 */
int xbt_graph_parse_get_leng  (void)
{
        return xbt_graph_parse_leng;
}

/** Get the current token.
 * 
 */

char *xbt_graph_parse_get_text  (void)
{
        return xbt_graph_parse_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void xbt_graph_parse_set_lineno (int  line_number )
{
    
    xbt_graph_parse_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see xbt_graph_parse__switch_to_buffer
 */
void xbt_graph_parse_set_in (FILE *  in_str )
{
        xbt_graph_parse_in = in_str ;
}

void xbt_graph_parse_set_out (FILE *  out_str )
{
        xbt_graph_parse_out = out_str ;
}

int xbt_graph_parse_get_debug  (void)
{
        return xbt_graph_parse__flex_debug;
}

void xbt_graph_parse_set_debug (int  bdebug )
{
        xbt_graph_parse__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from xbt_graph_parse_lex_destroy(), so don't allocate here.
     */

    /* We do not touch xbt_graph_parse_lineno unless the option is enabled. */
    xbt_graph_parse_lineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    xbt_graph_parse_in = stdin;
    xbt_graph_parse_out = stdout;
#else
    xbt_graph_parse_in = (FILE *) 0;
    xbt_graph_parse_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * xbt_graph_parse_lex_init()
     */
    return 0;
}

/* xbt_graph_parse_lex_destroy is for both reentrant and non-reentrant scanners. */
int xbt_graph_parse_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		xbt_graph_parse__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		xbt_graph_parse_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	xbt_graph_parse_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        xbt_graph_parse_free((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * xbt_graph_parse_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *xbt_graph_parse_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *xbt_graph_parse_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void xbt_graph_parse_free (void * ptr )
{
	free( (char *) ptr );	/* see xbt_graph_parse_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

/* Element context stack lookup. */
int graphxml_element_context(int i)
{
  return (0<i && i<yy_start_stack_depth
	  ? yy_start_stack[yy_start_stack_ptr - i]
	  : 0);
}

#ifdef FLEX_DEBUG
void print_yy_stack(char* fmt, ...)
{
  int i = 0; va_list ap; va_start(ap, fmt);
  vfprintf(stderr, fmt, ap);
  if (graphxml_statenames) {
      for (i=1; i<yy_start_stack_ptr; i++) {
          fprintf(stderr, "%s/", graphxml_statenames[yy_start_stack[i] ]);
      }
      fprintf(stderr,"%s\n", graphxml_statenames[YY_START]);
  }
  va_end(ap);
}

void print_graphxml_bufferstack()
{
    int i;
    fputs("Buffer: ", stderr);
    for (i = 0; i < blimit; i++) {
       if ( graphxml_bufferstack[i] == '\377' ) break;
         putc(graphxml_bufferstack[i], stderr);
    }
    putc('\n', stderr);
}

static void debug_enter(int state, const char* statename) {
  yy_push_state(state);
  if (xbt_graph_parse__flex_debug) {
       print_yy_stack("--ENTER(%s) : ",statename);
       print_graphxml_bufferstack();
  }
}

static void debug_leave(void) {
    if (xbt_graph_parse__flex_debug) {
        print_yy_stack("--LEAVE : ");
	print_graphxml_bufferstack();
    }
  yy_pop_state();
}

static void debug_set(int state, const char* statename) {
  BEGIN(state);
  if (xbt_graph_parse__flex_debug) print_yy_stack("--SET(%s) : ",statename);
}
#endif

static void cleanup(void)
{
    if (graphxml_statenames) {
        free(graphxml_statenames);
	graphxml_statenames = NULL;
    }
    free(graphxml_bufferstack);
    graphxml_bufferstack = NULL;

    free(indexstack);
    indexstack = NULL;
}

static int fail(const char* fmt, ...)
{
    int chars_left, used;
    va_list ap; va_start(ap, fmt);
#ifdef FLEXML_yylineno
    used = sprintf(flexml_err_msg,
		   "Invalid XML (XML input line %d, state %d): ",
		   xbt_graph_parse_lineno, YY_START);
#else
    used = sprintf(flexml_err_msg,
		   "Invalid XML (state %d): ",
		   YY_START);
#endif
    chars_left = flexml_max_err_msg_size - used - 1;
    vsnprintf(flexml_err_msg + used, chars_left, fmt, ap);
    va_end(ap);

#ifndef FLEXML_quiet_parser
    /* print directly to sdterr */
    fprintf(stderr, "%s\n", flexml_err_msg);
    flexml_err_msg[0] = '\0';
#endif

    cleanup();

    return 1;
}

